==> tbmodels-1.3.2.tar.gz: tbmodels-1.3.2/tbmodels/_sparse_matrix.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# (c) 2015-2018, ETH Zurich, Institut fuer Theoretische Physik
# Author: Dominik Gresch <greschd@gmx.ch>
"""
Helper module wrapping scipy.sparse matrix types to make them
convertible directly to numpy arrays by implementing the __array__
method.
"""

import scipy.sparse as sp


class ArrayConvertible:
    """
    Base class for sparse matrix types that should be directly convertible
    to numpy arrays.
    """
    def __array__(self):
        return self.toarray()  # pylint: disable=no-member

    # Because transpose / conjugate return scipy sparse arrays.
    def transpose(self):
        return self.__class__(super(ArrayConvertible, self).transpose())  # pylint: disable=no-member

    def conjugate(self):
        return self.__class__(super(ArrayConvertible, self).conjugate())  # pylint: disable=no-member


class csr(ArrayConvertible, sp.csr_matrix):  # pylint: disable=invalid-name
    """
    Wrapper for CSR matrices to be array-convertible.
    """
    def __repr__(self):
        res = (
            'csr((' + '[' + ', '.join(str(x)
                                      for x in self.data) + '], ' + '[' + ', '.join(str(x)
                                                                                    for x in self.indices) + '], ' +
            '[' + ', '.join(str(x) for x in self.indptr) + ']), ' + 'shape={0.shape}, dtype=np.{0.dtype})'.format(self)
        )
        return res

    # This is here because scipy throws NotImplementedError
    # Is not needed for newer versions of scipy
    def __iadd__(self, other):
        return self + other


class coo(ArrayConvertible, sp.coo_matrix):  # pylint: disable=invalid-name
    """
    Wrapper for COO matrices to be array-convertible.
    """


class lil(ArrayConvertible, sp.lil_matrix):  # pylint: disable=invalid-name
    """
    Wrapper for LIL matrices to be array-convertible.
    """

==> tbmodels-1.4.0rc2.tar.gz: tbmodels-1.4.0rc2/tbmodels/_sparse_matrix.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# (c) 2015-2018, ETH Zurich, Institut fuer Theoretische Physik
# Author: Dominik Gresch <greschd@gmx.ch>
"""
Helper module wrapping scipy.sparse matrix types to make them
convertible directly to numpy arrays by implementing the __array__
method.
"""

import scipy.sparse as sp


class ArrayConvertible:
    """
    Base class for sparse matrix types that should be directly convertible
    to numpy arrays.
    """

    def __array__(self):
        return self.toarray()  # pylint: disable=no-member

    # Because transpose / conjugate return scipy sparse arrays.
    def transpose(self):
        return self.__class__(super().transpose())  # pylint: disable=no-member

    def conjugate(self):
        return self.__class__(super().conjugate())  # pylint: disable=no-member


class csr(ArrayConvertible, sp.csr_matrix):  # pylint: disable=invalid-name
    """
    Wrapper for CSR matrices to be array-convertible.
    """

    def __repr__(self):
        res = (
            "csr(("
            + "["
            + ", ".join(str(x) for x in self.data)
            + "], "
            + "["
            + ", ".join(str(x) for x in self.indices)
            + "], "
            + "["
            + ", ".join(str(x) for x in self.indptr)
            + "]), "
            + "shape={0.shape}, dtype=np.{0.dtype})".format(self)
        )
        return res

    # This is here because scipy throws NotImplementedError
    # Is not needed for newer versions of scipy
    def __iadd__(self, other):
        return self + other


class coo(ArrayConvertible, sp.coo_matrix):  # pylint: disable=invalid-name
    """
    Wrapper for COO matrices to be array-convertible.
    """


class lil(ArrayConvertible, sp.lil_matrix):  # pylint: disable=invalid-name
    """
    Wrapper for LIL matrices to be array-convertible.
    """
